@@ -12,7 +12,6 @@
 
 AgentConfigModel::AgentConfigModel(QObject *parent)
     : QAbstractTableModel(parent)
-    , m_interface(nullptr)
 {
 }
 
@@ -82,7 +81,7 @@ int AgentConfigModel::rowCount(const QModelIndex &parent) const
 QVariant AgentConfigModel::data(const QModelIndex &index, int role) const
 {
     if (index.row() < 0 || index.row() >= m_settings.size()) {
-        return QVariant();
+        return {};
     }
     QPair<QString, QVariant> setting = m_settings.at(index.row());
     if (role == Qt::DisplayRole || role == Qt::EditRole) {
@@ -98,7 +97,7 @@ QVariant AgentConfigModel::data(const QModelIndex &index, int role) const
             return QLatin1String(setting.second.typeName());
         }
     }
-    return QVariant();
+    return {};
 }
 
 bool AgentConfigModel::setData(const QModelIndex &index, const QVariant &value, int role)
