@@ -59,8 +59,6 @@
 #include <QFileDialog>
 #include <QMenu>
 #include <QSplitter>
-#include <QSqlError>
-#include <QSqlQuery>
 #include <QStandardItemModel>
 #include <QTimer>
 #include <QVBoxLayout>
@@ -70,6 +68,7 @@
 #include <Akonadi/ContactViewer>
 #include <CalendarSupport/IncidenceViewer>
 #include <MessageViewer/Viewer>
+#include <kwidgetsaddons_version.h>
 #endif
 
 using namespace Akonadi;
@@ -617,14 +616,23 @@ void BrowserWidget::tagViewDoubleClicked(const QModelIndex &index)
 
 void BrowserWidget::removeTagRequested()
 {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (KMessageBox::questionTwoActions(this,
+#else
     if (KMessageBox::questionYesNo(this,
-                                   QStringLiteral("Do you really want to remove selected tag?"),
-                                   QStringLiteral("Delete tag?"),
-                                   KStandardGuiItem::del(),
-                                   KStandardGuiItem::cancel(),
-                                   QString(),
-                                   KMessageBox::Dangerous)
+
+#endif
+                                        QStringLiteral("Do you really want to remove selected tag?"),
+                                        QStringLiteral("Delete tag?"),
+                                        KStandardGuiItem::del(),
+                                        KStandardGuiItem::cancel(),
+                                        QString(),
+                                        KMessageBox::Dangerous)
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        == KMessageBox::ButtonCode::SecondaryAction) {
+#else
         == KMessageBox::No) {
+#endif
         return;
     }
 
